@@ -4,7 +4,7 @@ import pandas as pd
 from statsmodels.tsa.stattools import grangercausalitytests
 import statsmodels.tsa.stattools as sts
 
-def fis_variable_frecuency(df_cat):
+def variable_frecuency(df_cat):
     """
     Salida en formato DataFrame de la frecuencia de las variables categoricas en %
     """
@@ -14,7 +14,7 @@ def fis_variable_frecuency(df_cat):
                 .sort_values(by = ['Variable','Frecuencia'])
     return(resultado)
     
-def fis_all_continous_statistics(df_cont):
+def all_continous_statistics(df_cont):
     """
     Salida en formato DataFrame de todos los estadísticos de variable contínua + mediana
     """
@@ -27,7 +27,7 @@ def fis_all_continous_statistics(df_cont):
     #Lo devolvemos
     return(estadisticos)
     
-def fis_eda_categoric_graph(df_cat):
+def eda_categoric_graph(df_cat):
     """
     Salida gráfica de todas las variables categoricas para exploration data analysis
     """
@@ -49,7 +49,7 @@ def fis_eda_categoric_graph(df_cat):
     plt.tight_layout()
     plt.show()
         
-def fis_eda_continous_graph(df_cont,mode='density'):
+def eda_continous_graph(df_cont,mode='density'):
     """
     Salida gráfica de todas las variables continuas para exploration data analysis
     """
@@ -75,7 +75,7 @@ def fis_eda_continous_graph(df_cont,mode='density'):
     plt.show()
         
 
-def fis_preprocessing_strong_corr(df,lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
+def preprocessing_strong_corr(df,lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
     """
     Extracción de variables correlacionadas a partir de un umbral lim_inf y tope lim_sup
     """
@@ -93,7 +93,7 @@ def fis_preprocessing_strong_corr(df,lim_inf = 0.3, lim_sup = 1,drop_dupli=True)
     #Devuelve la salida
     return(c)
     
-def fis_preprocessing_ranking_mi(mutual_selector, predictors_df, modo = 'tabla'):
+def preprocessing_ranking_mi(mutual_selector, predictors_df, modo = 'tabla'):
     """
     Salida Mejorada de la salida from sklearn.feature_selection import mutual_info_classif
     """
@@ -110,14 +110,14 @@ def fis_preprocessing_ranking_mi(mutual_selector, predictors_df, modo = 'tabla')
         g.set_yticklabels(ranking_mi.sort_values(by = 'importancia_mi').variable)
         return(g)
 
-def fis_preprocessing_ranking_rfe(predictoras,rfe_ranking):
+def preprocessing_ranking_rfe(predictoras,rfe_ranking):
     """
     Salida Mejorada de la salida from sklearn.feature_selection import RFECV
     """
     rank_rfe = pd.DataFrame({'variable': predictoras.columns, 'ranking_rfe': rfe_ranking}).sort_values(by = 'ranking_rfe')
     return(rank_rfe)
  
-def fis_preprocessing_ranking_per(predictoras,permutacion,modo='tabla'):
+def preprocessing_ranking_per(predictoras,permutacion,modo='tabla'):
     """
     Salida Mejorada de la salida from sklearn.inspection import permutation_importance
     """
@@ -128,7 +128,7 @@ def fis_preprocessing_ranking_per(predictoras,permutacion,modo='tabla'):
     else:
         ranking_per.set_index('variable').importancia_per.sort_values().plot.barh(figsize = (8,10));
     
-def fis_preprocessing_ranking_tot(rank_mi, rank_rfe,rank_per,modo='tabla'):
+def preprocessing_ranking_tot(rank_mi, rank_rfe,rank_per,modo='tabla'):
     """
     Comparativa de todos los rankings (mi, rfe, permutation) grafica y por tabla
     """
@@ -141,7 +141,7 @@ def fis_preprocessing_ranking_tot(rank_mi, rank_rfe,rank_per,modo='tabla'):
     else:
         ranking_tot.set_index('variable').puntos.sort_values(ascending = False).plot.barh(figsize = (8,10));
         
-def fis_outliers_standard_desv(variable, x = 4):
+def outliers_standard_desv(variable, x = 4):
     """
     Dada una variable sacamos los índices de un Dataframe para aquellos registors que su valor 
     esté en un umbral de la media mas/menos x veces la desviación estándard de la muestra
@@ -160,7 +160,7 @@ def fis_outliers_standard_desv(variable, x = 4):
     return(indices)
     
 # Invirtiendo la transformación
-def fis_TS_invert_transformation(X_train, pred):
+def TS_invert_transformation(X_train, pred):
     """
     Los pronósticos se generan en la escala de los datos de entrenamiento utilizados por el modelo, es decir, son datos transformados. 
     Entonces, para volver a ponerlos en su escala original, necesitamos des-diferenciarlos.
@@ -181,7 +181,7 @@ def fis_TS_invert_transformation(X_train, pred):
     return forecast
   
 
-def fis_TS_grangers_causality_matrix(X_train_transformed, test = 'ssr_chi2test', verbose=False,maxlag=15):
+def TS_grangers_causality_matrix(X_train_transformed, test = 'ssr_chi2test', verbose=False,maxlag=15):
     """
     Causalidad de Granger (Wiener-Granger), Los valores de la TS ha de ser estacionaria
     
@@ -203,7 +203,7 @@ def fis_TS_grangers_causality_matrix(X_train_transformed, test = 'ssr_chi2test',
     dataset.index = [var + '_y' for var in variables]
     return dataset
   
-def fis_TS_dickey_fuller_statistics(X_train):
+def TS_dickey_fuller_statistics(X_train):
     """
     Dickey Fuller test, para diferentes columnas de un DataFrame que correspondan a series temporales.
     Si los p-valores son mayores que 0.05, No se rechaza la hipótesis nula de que la serie no es estacionaria. 
