@@ -1,4 +1,4 @@
-def fis_tools_clean_df_columns(df):
+def tools_clean_df_columns(df):
     """
     Pasamos un DataFrame y nos lo devuelve con las columnas con un correcto formato para trabajo
     """
@@ -17,7 +17,7 @@ def fis_tools_clean_df_columns(df):
         df.rename({col: new_col}, axis=1, inplace=True)
     return df
 	
-def fis_tools_quitar_tildes(palabra):
+def tools_quitar_tildes(palabra):
     """
     Limpieza de tildes para análisis
     """
